from ezdiscord import EasyDiscord

# Create an instance of EasyDiscord
easy_discord_bot = EasyDiscord()

# Add a command using addstock method
easy_discord_bot.addstock()

# Run the bot with your Discord bot token
token = "MTIwMzAwNDYzNTQ3Mjk5NDM4Ng.G1WzZR.iaUSuVCvsDqfzUsKNEEeAotnxuI99_AhWOzHo0"
easy_discord_bot.run_bot(token)



from setuptools import setup, find_packages
 
classifiers = [
  'Development Status :: 5 - Production/Stable',
  'Intended Audience :: Education',
  'Operating System :: Microsoft :: Windows :: Windows 10',
  'License :: OSI Approved :: MIT License',
  'Programming Language :: Python :: 3'
]
 
setup(
  long_description=open('README.rst').read(),
  name='ezdiscord',
  version='1.0.8',
  description='Made discord.py easier.',
  url='',  
  author='Karmin',
  license='MIT', 
  classifiers=classifiers,
  keywords='Made discord.py easier.',
  packages=find_packages(),
  install_requires=['os', 'discord.py'] 
)


import discord
from discord import Intents
from discord.ext import commands

class EasyDiscord():
    def __init__(self):
        self.client = commands.Bot(command_prefix='!')
        self.intents = Intents.default()
        self.intents.message_content = True

    def addstock(self):
        @self.client.command()
        async def add(ctx, name, *args):
            server_name = ctx.guild.name

            # Open the file in 'a+' mode to append instead of overwrite
            with open(f"{server_name}_{name}.txt", 'a+') as file:
                # Join the arguments to form a single string with each argument on a new line
                content = '\n'.join(args)
                file.write(f"{content}\n")

            await ctx.reply("Done!")

    def run_bot(self, token):
        self.client.run(token)
